ApiService class

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({required String? endpoint, required Method method, Map<String, dynamic> body = const {}, List<Map<String, dynamic>> files = const []}) Future<Response>
cancelServiceRequest(int id, String reason) Future<ApiResponse<bool>>
Cancel a service request
createServiceRequest(ServiceRequest request) Future<ApiResponse<ServiceRequest>>
Create a new service request
getActiveServices() Future<ApiResponse<List<Service>>>
Get all active services
getUser() Future<ApiResponse<User>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited